@@ -16,6 +16,8 @@ TOKEN_NAME = os.environ.get('TOKEN_NAME', "middle_auth_token")
 CACHE_MAXSIZE = int(os.environ.get('TOKEN_CACHE_MAXSIZE', "1024"))
 CACHE_TTL = int(os.environ.get('TOKEN_CACHE_TTL', "300"))
 
+AUTH_DISABLED = os.environ.get('AUTH_DISABLED', "false") == "true"
+
 r = None
 if USE_REDIS:
     import redis
@@ -27,6 +29,9 @@ class AuthorizationError(Exception):
     pass
 
 def get_usernames(user_ids, token=None):
+    if AUTH_DISABLED:
+        return []
+
     if token is None:
         raise ValueError('missing token')
     if len(user_ids):
@@ -63,6 +68,9 @@ def is_root_public(table_id, root_id, token):
     if root_id is None:
         return False
 
+    if AUTH_DISABLED:
+        return True
+
     url = f"https://{AUTH_URL}/api/v1/table/{table_id}/root/{root_id}/is_public"
 
     req = requests.get(url, headers={'authorization': 'Bearer ' + token}, timeout=5)
@@ -74,6 +82,9 @@ def is_root_public(table_id, root_id, token):
 
 @cachetools.func.ttl_cache(maxsize=CACHE_MAXSIZE, ttl=CACHE_TTL)
 def table_has_public(table_id, token):
+    if AUTH_DISABLED:
+        return True
+
     url = f"https://{AUTH_URL}/api/v1/table/{table_id}/has_public"
 
     req = requests.get(url, headers={'authorization': 'Bearer ' + token}, timeout=5)
@@ -94,22 +105,6 @@ def auth_required(func=None, *, required_permission=None, public_table_key=None,
                 # this allows auth_required to be an optional decorator if auth_requires_role is also used
                 return f(*args, **kwargs)
 
-            token = None
-            cookie_name = TOKEN_NAME
-
-            auth_header = flask.request.headers.get('authorization')
-            xrw_header = flask.request.headers.get('X-Requested-With')
-
-            programmatic_access = xrw_header or auth_header or flask.request.environ.get('HTTP_ORIGIN')
-
-            AUTHORIZE_URI = 'https://' + STICKY_AUTH_URL + '/api/v1/authorize'
-
-            query_param_token = flask.request.args.get(TOKEN_NAME)
-
-            if not query_param_token:
-                # deprecated
-                query_param_token = flask.request.args.get('token')
-
             flask.g.public_access_cache = None
             def lazy_check_public_access():
                 if flask.g.public_access_cache is None:
@@ -127,29 +122,47 @@ def auth_required(func=None, *, required_permission=None, public_table_key=None,
 
             flask.g.public_access = lazy_check_public_access
 
+            if AUTH_DISABLED:
+                flask.g.auth_user = {'id': 0, 'service_account': False, 'name': 'AUTH_DISABLED', 'email': 'AUTH_DISABLED@AUTH.DISABLED', 'admin': True, 'groups': [], 'permissions': {}}
+                flask.g.auth_token = 'AUTH_DISABLED'
+                return f(*args, **kwargs)
+
+            cookie_name = TOKEN_NAME
+            token = flask.request.cookies.get(cookie_name)
+
+            auth_header = flask.request.headers.get('authorization')
+            xrw_header = flask.request.headers.get('X-Requested-With')
+
+            programmatic_access = xrw_header or auth_header or flask.request.environ.get('HTTP_ORIGIN')
+
+            AUTHORIZE_URI = 'https://' + STICKY_AUTH_URL + '/api/v1/authorize'
+
+            query_param_token = flask.request.args.get(TOKEN_NAME)
+
+            if query_param_token:
+                token = query_param_token
+
+            auth_header = flask.request.headers.get('authorization')
+
+            if auth_header:
+                if not auth_header.startswith('Bearer '):
+                    resp = flask.Response("Invalid Request", 400)
+                    resp.headers['WWW-Authenticate'] = 'Bearer realm="' + AUTHORIZE_URI + '", error="invalid_request", error_description="Header must begin with \'Bearer\'"'
+                    return resp
+                else: # auth header takes priority
+                    token = auth_header.split(' ')[1] # remove schema
+
             if programmatic_access:
-                if query_param_token:
-                    token = query_param_token
-                else:
-                    if not auth_header:
-                        if not flask.g.public_access():
-                            resp = flask.Response("Unauthorized", 401)
-                            resp.headers['WWW-Authenticate'] = 'Bearer realm="' + AUTHORIZE_URI + '"'
-                            return resp
-                    elif not auth_header.startswith('Bearer '):
-                        resp = flask.Response("Invalid Request", 400)
-                        resp.headers['WWW-Authenticate'] = 'Bearer realm="' + AUTHORIZE_URI + '", error="invalid_request", error_description="Header must begin with \'Bearer\'"'
-                        return resp
-                    else:
-                        token = auth_header.split(' ')[1] # remove schema
+                if not token and not flask.g.public_access():
+                    resp = flask.Response("Unauthorized", 401)
+                    resp.headers['WWW-Authenticate'] = 'Bearer realm="' + AUTHORIZE_URI + '"'
+                    return resp
             else: # direct browser access, or a non-browser request missing auth header (user error) TODO: check user agent to deliver 401 in this case
                 if query_param_token:
                     resp = flask.make_response(flask.redirect(furl(flask.request.url).remove([TOKEN_NAME, 'token']).url, code=302))
                     resp.set_cookie(cookie_name, query_param_token, secure=True, httponly=True)
                     return resp
 
-                token = flask.request.cookies.get(cookie_name)
-
             cached_user_data = get_user_cache(token) if token else None
 
             if cached_user_data:
@@ -189,7 +202,7 @@ def auth_requires_admin(f):
 
     return decorated_function
 
-def auth_requires_permission(required_permission, public_table_key=None, public_node_key=None, service_token=None):
+def auth_requires_permission(required_permission, public_table_key=None, public_node_key=None, service_token=None, dataset=None):
     def decorator(f):
         @wraps(f)
         @auth_required(required_permission=required_permission, public_table_key=public_table_key, public_node_key=public_node_key, service_token=service_token)
@@ -197,28 +210,29 @@ def auth_requires_permission(required_permission, public_table_key=None, public_
             if flask.request.method == 'OPTIONS':
                 return f(*args, **{**kwargs, **{'table_id': table_id}})
 
-            table_id_to_dataset = {
-                "pinky100_sv16": "pinky100",
-                "pinky100_neo1": "pinky100",
-                "akhilesh-pinky100-0": "pinky100",
-                "anp0": "pinky100",
-                "minnie3_v0": "minnie65",
-                "anm0": "minnie65",
-                "fly_v26": "fafb_sandbox",
-                "fly_v31": "fafb",
-                "fly_arv0": "fafb"
-            }
+            if dataset is None:
+                table_id_to_dataset = {
+                    "pinky100_sv16": "pinky100",
+                    "pinky100_neo1": "pinky100",
+                    "akhilesh-pinky100-0": "pinky100",
+                    "anp0": "pinky100",
+                    "minnie3_v0": "minnie65",
+                    "anm0": "minnie65",
+                    "fly_v26": "fafb_sandbox",
+                    "fly_v31": "fafb",
+                    "fly_arv0": "fafb"
+                }
 
-            if table_id in table_id_to_dataset:
-                dataset = table_id_to_dataset.get(table_id)
-            elif table_id.startswith("pinky100_rv") or \
-                    table_id.startswith("pinky100_arv") or \
-                    table_id.startswith("pinky_nf"):
-                dataset = "pinky100"
-            elif table_id.startswith("minnie3_v"):
-                dataset = "minnie65"
-            else:
-                raise Exception("Unknown dataset")
+                if table_id in table_id_to_dataset:
+                    dataset = table_id_to_dataset.get(table_id)
+                elif table_id.startswith("pinky100_rv") or \
+                        table_id.startswith("pinky100_arv") or \
+                        table_id.startswith("pinky_nf"):
+                    dataset = "pinky100"
+                elif table_id.startswith("minnie3_v"):
+                    dataset = "minnie65"
+                else:
+                    raise Exception("Unknown dataset")
 
             if dataset is not None:
                 has_permission = required_permission in flask.g.auth_user.get('permissions_v2', {}).get(dataset, [])
@@ -228,7 +242,7 @@ def auth_requires_permission(required_permission, public_table_key=None, public_
                     level_for_dataset = flask.g.auth_user.get('permissions', {}).get(dataset, 0)
                     has_permission = level_for_dataset >= required_level
 
-                if has_permission or flask.g.public_access(): # public_access won't be true for edit requests
+                if AUTH_DISABLED or has_permission or flask.g.public_access(): # public_access won't be true for edit requests
                     return f(*args, **{**kwargs, **{'table_id': table_id}})
                 else:
                     resp = flask.Response("Missing permission: {0} for dataset {1}".format(required_permission, dataset), 403)
@@ -248,7 +262,7 @@ def auth_requires_group(required_group):
             if flask.request.method == 'OPTIONS':
                 return f(*args, **kwargs)
 
-            if required_group not in flask.g.auth_user['groups']:
+            if not AUTH_DISABLED and required_group not in flask.g.auth_user['groups']:
                 resp = flask.Response("Requires membership of group: {0}".format(required_group), 403)
                 return resp
 
